[coreboot-gerrit] New patch to review for coreboot: b10182e i2c/ww_ring: change colors for different display modes

Patrick Georgi (pgeorgi@google.com) gerrit at coreboot.org
Tue Apr 21 10:45:01 CEST 2015


Patrick Georgi (pgeorgi at google.com) just uploaded a new patch set to gerrit, which you can find at http://review.coreboot.org/9880

-gerrit

commit b10182ece2233027526bd959824efeba87a570a0
Author: Vadim Bendebury <vbendeb at chromium.org>
Date:   Sat Mar 21 15:13:03 2015 -0700

    i2c/ww_ring:  change colors for different display modes
    
    Modify colors as suggested by product review folks. This is not final,
    to make it easier to identify RGB locations in the hex dumps, express
    their values in decimal as opposed to hex.
    
    BRANCH=storm
    BUG=chrome-os-partner:36059
    TEST=verified new all three color schemes while pressing the recovery
         button at boot for 20 seconds.
    
    Change-Id: I7461acd7004e3d10cba6665a9bfe25ec8aa6f3ba
    Signed-off-by: Patrick Georgi <pgeorgi at chromium.org>
    Original-Commit-Id: 7a075824a1954eb5d1b65ce887304924724a6d21
    Original-Change-Id: I7f5968e361333572fd1f84aa11b7150194ad902a
    Original-Signed-off-by: Vadim Bendebury <vbendeb at chromium.org>
    Original-Reviewed-on: https://chromium-review.googlesource.com/261690
    Original-Reviewed-by: Aaron Durbin <adurbin at chromium.org>
---
 src/drivers/i2c/ww_ring/ww_ring_programs.c | 36 +++++++++++++++---------------
 1 file changed, 18 insertions(+), 18 deletions(-)

diff --git a/src/drivers/i2c/ww_ring/ww_ring_programs.c b/src/drivers/i2c/ww_ring/ww_ring_programs.c
index 8f32a76..9981656 100644
--- a/src/drivers/i2c/ww_ring/ww_ring_programs.c
+++ b/src/drivers/i2c/ww_ring/ww_ring_programs.c
@@ -69,20 +69,20 @@ row_blue:  dw 0000000100100100b
 /* RGB set to 000000, resulting in all LEDs off. */
 static const uint8_t solid_000000_text[] = {
 	0x00, 0x49, 0x00, 0x92, 0x01, 0x24, 0x9F, 0x80,
-	0x40, 0x00, 0xC0, 0x00, 0x9F, 0x81, 0x40, 0x00,
-	0xC0, 0x00, 0x9F, 0x82, 0x40, 0x00, 0xC0, 0x00
+	0x40,    0, 0xC0, 0x00, 0x9F, 0x81, 0x40,    0,
+	0xC0, 0x00, 0x9F, 0x82, 0x40,    0, 0xC0, 0x00
 };
 
-/* RGB set to 010101, resulting in a bleak greyish color. */
-static const uint8_t solid_010101_text[] = {
+/* Rgb set to 128, resulting in a brightish white color. */
+static const uint8_t solid_808080_text[] = {
 	0x00, 0x49, 0x00, 0x92, 0x01, 0x24, 0x9F, 0x80,
-	0x40, 0x01, 0xC0, 0x00, 0x9F, 0x81, 0x40, 0x01,
-	0xC0, 0x00, 0x9F, 0x82, 0x40, 0x01, 0xC0, 0x00
+	0x40,  128, 0xC0, 0x00, 0x9F, 0x81, 0x40,  128,
+	0xC0, 0x00, 0x9F, 0x82, 0x40,  128, 0xC0, 0x00
 };
 
-static const TiLp55231Program solid_010101_program = {
-	solid_010101_text,
-	sizeof(solid_010101_text),
+static const TiLp55231Program solid_808080_program = {
+	solid_808080_text,
+	sizeof(solid_808080_text),
 	0,
 	{ 3, 6, 9 }
 };
@@ -207,8 +207,8 @@ wait2:
 static const uint8_t blink_wipeout1_text[] = {
 	0x00,  0x49,  0x00,  0x92,  0x01,  0x24,  0x90,  0x02,
 	0x94,  0x02,  0x9f,  0x80,  0xf0,  0x00,  0xe0,  0x40,
-	0x98,  0xff,  0x84,  0x62,  0x9f,  0x81,  0x98,  0xff,
-	0x84,  0x62,  0x9f,  0x82,  0x98,  0x00,  0x84,  0x62,
+	0x98,   255,  0x84,  0x62,  0x9f,  0x81,  0x98,   238,
+	0x84,  0x62,  0x9f,  0x82,  0x98,    80,  0x84,  0x62,
 	0x4c,  0x00,  0x86,  0x34,  0xe0,  0x40,  0x40,  0x00,
 	0x9f,  0x81,  0x40,  0x00,  0x9f,  0x80,  0x40,  0x00,
 	0x4c,  0x00,  0x86,  0x55,  0xa0,  0x04,  0xc0,  0x00,
@@ -216,8 +216,8 @@ static const uint8_t blink_wipeout1_text[] = {
 };
 
 static const uint8_t blink_wipeout2_text[] = {
-	0x00,  0x49,  0x00,  0x92,  0x01,  0x24,  0x90,  0xff,
-	0x94,  0xff,  0x98,  0x00,  0xe0,  0x40,  0x9f,  0x80,
+	0x00,  0x49,  0x00,  0x92,  0x01,  0x24,  0x90,   255,
+	0x94,   238,  0x98,    80,  0xe0,  0x40,  0x9f,  0x80,
 	0xf0,  0x00,  0x84,  0x60,  0x9f,  0x81,  0x84,  0x61,
 	0x9f,  0x82,  0x84,  0x62,  0x4c,  0x00,  0xa0,  0x8b,
 	0xf0,  0x00,  0x40,  0x00,  0x9f,  0x81,  0x40,  0x00,
@@ -241,8 +241,8 @@ static const TiLp55231Program blink_wipeout2_program = {
 static const uint8_t blink_recovery1_text[] = {
 	0x00,  0x49,  0x00,  0x92,  0x01,  0x24,  0x90,  0x02,
 	0x94,  0x02,  0x9f,  0x80,  0xf0,  0x00,  0xe0,  0x40,
-	0x98,  0xff,  0x84,  0x62,  0x9f,  0x81,  0x98,  0x3d,
-	0x84,  0x62,  0x9f,  0x82,  0x98,  0x00,  0x84,  0x62,
+	0x98,   255,  0x84,  0x62,  0x9f,  0x81,  0x98,    61,
+	0x84,  0x62,  0x9f,  0x82,  0x98,     0,  0x84,  0x62,
 	0x4c,  0x00,  0x86,  0x34,  0xe0,  0x40,  0x40,  0x00,
 	0x9f,  0x81,  0x40,  0x00,  0x9f,  0x80,  0x40,  0x00,
 	0x4c,  0x00,  0x86,  0x55,  0xa0,  0x04,  0xc0,  0x00,
@@ -255,8 +255,8 @@ static const TiLp55231Program blink_recovery1_program = {
 	{ 3,  27,  28,  }
 };
 static const uint8_t blink_recovery2_text[] = {
-	0x00,  0x49,  0x00,  0x92,  0x01,  0x24,  0x90,  0xff,
-	0x94,  0x3d,  0x98,  0x00,  0xe0,  0x40,  0x9f,  0x80,
+	0x00,  0x49,  0x00,  0x92,  0x01,  0x24,  0x90,   255,
+	0x94,    61,  0x98,     0,  0xe0,  0x40,  0x9f,  0x80,
 	0xf0,  0x00,  0x84,  0x60,  0x9f,  0x81,  0x84,  0x61,
 	0x9f,  0x82,  0x84,  0x62,  0x4c,  0x00,  0xa0,  0x8b,
 	0xf0,  0x00,  0x40,  0x00,  0x9f,  0x81,  0x40,  0x00,
@@ -277,7 +277,7 @@ const WwRingStateProg wwr_state_programs[] = {
 	 * be changed soon.
 	 */
 	{WWR_ALL_OFF, {&solid_000000_program, &solid_000000_program} },
-	{WWR_RECOVERY_PUSHED, {&solid_010101_program, &solid_010101_program} },
+	{WWR_RECOVERY_PUSHED, {&solid_808080_program, &solid_808080_program} },
 	{WWR_WIPEOUT_REQUEST, {&blink_wipeout1_program,
 			       &blink_wipeout2_program} },
 	{WWR_RECOVERY_REQUEST, {&blink_recovery1_program,



More information about the coreboot-gerrit mailing list